@@ -291,6 +291,12 @@ populate_model (NautilusBurnDriveSelection *selection,
                 drives = g_list_delete_link (drives, drives);
 	}
 
+	if (selection->priv->have_file_image) {
+		drive = nautilus_burn_drive_monitor_get_drive_for_image (selection->priv->monitor);
+		selection_append_drive (selection, drive);
+		nautilus_burn_drive_unref (drive);
+	}
+
 	gtk_combo_box_set_active (GTK_COMBO_BOX (selection), 0);
 }
 
@@ -385,44 +391,10 @@ nautilus_burn_drive_selection_new (void)
 }
 
 static void
-nautilus_burn_drive_selection_set_have_file_image (NautilusBurnDriveSelection *selection,
-						   gboolean                    have_file_image)
-{
-	NautilusBurnDrive *drive;
-
-	g_return_if_fail (selection != NULL);
-	g_return_if_fail (NAUTILUS_BURN_IS_DRIVE_SELECTION (selection));
-
-	if (selection->priv->have_file_image == have_file_image) {
-		return;
-	}
-
-	drive = nautilus_burn_drive_monitor_get_drive_for_image (selection->priv->monitor);
-
-	if (have_file_image == FALSE) {
-		selection_remove_drive (selection, drive);
-	} else {
-		selection_append_drive (selection, drive);
-	}
-
-	selection->priv->have_file_image = have_file_image;
-
-	selection_update_sensitivity (selection);
-}
-
-static void
-nautilus_burn_drive_selection_set_recorders_only (NautilusBurnDriveSelection *selection,
-						  gboolean                    recorders_only)
+repopulate_model (NautilusBurnDriveSelection *selection)
 {
 	GtkTreeModel *model;
 
-	g_return_if_fail (selection != NULL);
-	g_return_if_fail (NAUTILUS_BURN_IS_DRIVE_SELECTION (selection));
-
-	if (selection->priv->show_recorders_only == recorders_only) {
-		return;
-	}
-
 	/* block the combo changed signal handler until we're done */
 	g_signal_handlers_block_by_func (G_OBJECT (selection),
 					 combo_changed, selection);
@@ -436,8 +408,40 @@ nautilus_burn_drive_selection_set_recorders_only (NautilusBurnDriveSelection *se
 
 	/* Force a signal out */
 	combo_changed (GTK_COMBO_BOX (selection), (gpointer) selection);
+}
+
+static void
+nautilus_burn_drive_selection_set_have_file_image (NautilusBurnDriveSelection *selection,
+						   gboolean                    have_file_image)
+{
+	g_return_if_fail (selection != NULL);
+	g_return_if_fail (NAUTILUS_BURN_IS_DRIVE_SELECTION (selection));
+
+	if (selection->priv->have_file_image == have_file_image) {
+		return;
+	}
+
+	selection->priv->have_file_image = have_file_image;
+
+	repopulate_model (selection);
+	selection_update_sensitivity (selection);
+}
+
+static void
+nautilus_burn_drive_selection_set_recorders_only (NautilusBurnDriveSelection *selection,
+						  gboolean                    recorders_only)
+{
+	g_return_if_fail (selection != NULL);
+	g_return_if_fail (NAUTILUS_BURN_IS_DRIVE_SELECTION (selection));
+
+	if (selection->priv->show_recorders_only == recorders_only) {
+		return;
+	}
 
 	selection->priv->show_recorders_only = recorders_only;
+
+	repopulate_model (selection);
+	selection_update_sensitivity (selection);
 }
 
 static void
