@@ -35,6 +35,7 @@
 
 #include "nautilus-burn-drive.h"
 #include "nautilus-burn-drive-monitor.h"
+#include "ncb-rename-dialog.h"
 #include "make-iso.h"
 
 #include "ncb-selection.h"
@@ -312,7 +313,7 @@ ncb_hig_dialog (GtkMessageType type,
 					title);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog), "%s", reason);
 	gtk_window_set_title (GTK_WINDOW (error_dialog), "");
-	gtk_window_set_icon_name (GTK_WINDOW (error_dialog), "gnome-dev-cdrom");
+	gtk_window_set_icon_name (GTK_WINDOW (error_dialog), "nautilus-cd-burner");
 
 	gtk_container_set_border_width (GTK_CONTAINER (error_dialog), 5);
 
@@ -340,11 +341,12 @@ verify_source_location_contents (const char *text_uri,
 				 GList     **images,
 				 GError    **error)
 {
-	GList    *unreadable_paths = NULL;
-	GList    *image_paths      = NULL;
-	gboolean  only_images;
-	gint64    size;
-	int       res;
+	GList		*unreadable_paths	= NULL;
+	GList		*image_paths		= NULL;
+	NcbRenameDialog	*rename_dialog;
+	gboolean	 only_images;
+	gint64		 size;
+	int		 res;
 
 	if (images != NULL) {
 		*images = NULL;
@@ -352,6 +354,25 @@ verify_source_location_contents (const char *text_uri,
 
 	size = estimate_size (text_uri, &unreadable_paths, &image_paths, &only_images);
 
+	rename_dialog = ncb_rename_dialog_new ();
+	g_signal_connect (G_OBJECT (rename_dialog), "response",
+			  (GCallback)ncb_rename_dialog_response_cb, NULL);
+
+	/* Display the rename dialog if there are invalid filenames in
+	 * BURN_URI. */
+	if (ncb_rename_dialog_set_invalid_filenames (rename_dialog, BURN_URI)) {
+
+		/* The dialog renames the files directly in BURN_URI
+		 * for us. */
+		res = gtk_dialog_run (GTK_DIALOG (rename_dialog));
+		if (res == GTK_RESPONSE_CANCEL) {
+			gtk_widget_destroy (GTK_WIDGET (rename_dialog));
+
+			return FALSE;
+		}
+	}
+	gtk_widget_destroy (GTK_WIDGET (rename_dialog));
+
 	if (only_images == TRUE && size != 0) {
 		GtkWidget *dialog;
 		char      *msg;
@@ -507,12 +528,12 @@ verify_burn_folder (NcbSelection *selection,
         }
 
         if (! verify_source_location_contents (BURN_URI, size, &image_paths, error)) {
-                if (image_paths) {
+                if (image_paths != NULL) {
                         /* change the source type */
                         ncb_selection_set_source (selection, NCB_SELECTION_SOURCE_ISO, (char *)image_paths->data);
                         g_list_foreach (image_paths, (GFunc)g_free, NULL);
                         g_list_free (image_paths);
-                        return FALSE;
+                        return TRUE;
                 } else {
                         return FALSE;
                 }
@@ -654,7 +675,7 @@ create_default_label (void)
 
         now = g_date_new ();
 
-        g_date_set_time (now, time (NULL));
+        g_date_set_time_t (now, time (NULL));
 
         /*
           translators: see strftime man page for meaning of %b, %d and %Y
